@@ -1,4 +1,4 @@
-/* expIcomm.h - private symbols common to both expect program and library
+/* exp_int.h - private symbols common to both expect program and library
 
 Written by: Don Libes, libes@cme.nist.gov, NIST, 12/3/90
 
@@ -15,7 +15,7 @@ would appreciate credit if this program or parts of it are used.
 #define TRUE 1
 #endif
 
-#ifdef NO_MEMCPY
+#ifndef HAVE_MEMCPY
 #define memcpy(x,y,len) bcopy(y,x,len)
 #endif
 
