@@ -37,10 +37,6 @@ Don Libes, NIST, 12/19/92
  * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
  */
 
-#ifndef lint
-static char rcsid[] = "$Header: /rel/cvsfiles/devo/expect/exp_main_tk.c,v 1.19 1994/04/11 22:30:22 rob Exp $ SPRITE (Berkeley)";
-#endif
-
 /*#include "tkConfig.h"*/
 /*#include "tkInt.h"*/
 #include "tk.h"
@@ -60,16 +56,19 @@ static Tk_Window mainWindow;	/* The main window for the application.  If
 				 * NULL then the application no longer
 				 * exists. */
 static Tcl_Interp *interp;	/* Interpreter for this application. */
+#if 0
 char *tcl_RcFileName = NULL;	/* Name of a user-specific startup script
 				 * to source if the application is being run
 				 * interactively (e.g. "~/.wishrc").  Set
 				 * by Tcl_AppInit.  NULL means don't source
 				 * anything ever. */
+#endif
 static Tcl_DString command;	/* Used to assemble lines of terminal input
 				 * into Tcl commands. */
 static int tty;			/* Non-zero means standard input is a
 				 * terminal-like device.  Zero means it's
 				 * a file. */
+static char normalExitCmd[] = "exit";
 static char errorExitCmd[] = "exit 1";
 
 /*
@@ -138,23 +137,18 @@ char **argv;
 {
 	int i;
 
-#if 0
-	exp_tcl_debugger_available = 1;
-#endif
-
 	if (argc == 0) {
 		strcpy(interp->result,"-Debug flag needs 1 or 0 argument");
-		return TCL_ERROR;
+		return -1;
 	}
 
 	if (Tcl_GetInt(interp,argv[0],&i) != TCL_OK) {
-		return TCL_ERROR;
+		return -1;
 	}
 
 	if (i) {
 		Dbg_On(interp,0);
 	}
-/*	Dbg_Interactor(interp,exp_interpreter);*/
 
 	argc--;
 	for (i=0;i<argc;i++) {
@@ -180,13 +174,14 @@ char **argv;
 	exp_cmdlinecmds = 1;
 
 	rc = Tcl_Eval(interp,argv[0]);
+	if (rc == TCL_ERROR) return -1;
 
 	argc--;
 	for (i=0;i<argc;i++) {
 		argv[i] = argv[i+1];
 	}
 
-	return(rc == TCL_ERROR?TCL_ERROR:argc);
+	return argc;
 }
 
 /*
@@ -229,7 +224,7 @@ main(argc, argv)
     int argc;				/* Number of arguments. */
     char **argv;			/* Array of argument strings. */
 {
-    char *args, *p, *msg;
+    char *args, *p, *msg, *class;
     char buf[20];
     int code;
 	extern char *exp_argv0;
@@ -314,25 +309,40 @@ main(argc, argv)
     }
 
     /*
-     * Initialize the Tk application.
+     * Initialize the Tk application.  If a -name option was provided,
+     * use it;  otherwise, if a file name was provided, use the last
+     * element of its path as the name of the application; otherwise
+     * use the last element of the program name.  For the application's
+     * class, capitalize the first letter of the name.
      */
 
-#if TCL_MINOR_VERSION == 0
-    mainWindow = Tk_CreateMainWindow(interp, display, name);
+#if TK_MAJOR_VERSION >= 4
+    class = (char *) ckalloc((unsigned) (strlen(name) + 1));
+    strcpy(class, name);
+    class[0] = toupper((unsigned char) class[0]);
+    mainWindow = Tk_CreateMainWindow(interp, display, name, class);
 #else
+# if TK_MAJOR_VERSION == 3 && TK_MINOR_VERSION < 4
+    mainWindow = Tk_CreateMainWindow(interp, display, name);
+# else
     mainWindow = Tk_CreateMainWindow(interp, display, name, "Tk");
+# endif
 #endif
+
     if (mainWindow == NULL) {
 	fprintf(stderr, "%s\n", interp->result);
 	exit(1);
     }
-#if TCL_MINOR_VERSION == 0
+#if TK_MAJOR_VERSION == 3 && TK_MINOR_VERSION < 4
     Tk_SetClass(mainWindow, "Tk");
 #endif
     if (synchronize) {
 	XSynchronize(Tk_Display(mainWindow), True);
     }
+
+#if TK_MAJOR_VERSION < 4
     Tk_GeometryRequest(mainWindow, 200, 200);
+#endif
 
     /*
      * Make command-line arguments available in the Tcl variables "argc"
@@ -355,7 +365,15 @@ main(argc, argv)
     Tcl_SetVar(interp, "argv0", (fileName != NULL) ? fileName : argv[0],
 	    TCL_GLOBAL_ONLY);
     if (geometry != NULL) {
+#if TK_MAJOR_VERSION < 4
 	Tcl_SetVar(interp, "geometry", geometry, TCL_GLOBAL_ONLY);
+#else
+	Tcl_SetVar(interp, "geometry", geometry, TCL_GLOBAL_ONLY);
+	code = Tcl_VarEval(interp, "wm geometry . ", geometry, (char *) NULL);
+	if (code != TCL_OK) {
+	    fprintf(stderr, "%s\n", interp->result);
+	}
+#endif
     }
 
     /*
@@ -438,10 +456,12 @@ main(argc, argv)
 	if (exp_interactive) {
 		(void) exp_interpreter(interp);
 	} else if (exp_cmdfile) {
-		exp_interpret_cmdfile(interp,exp_cmdfile);
+		int rc = exp_interpret_cmdfile(interp,exp_cmdfile);
+		if (rc != TCL_OK) exp_exit(interp,rc);
 		Tk_MainLoop();
 	} else if (exp_cmdfilename) {
-		exp_interpret_cmdfilename(interp,exp_cmdfilename);
+		int rc = exp_interpret_cmdfilename(interp,exp_cmdfilename);
+		if (rc != TCL_OK) exp_exit(interp,rc);
 		Tk_MainLoop();
 	}
 
@@ -451,7 +471,7 @@ main(argc, argv)
      * to do additional cleanup.
      */
 
-    Tcl_Eval(interp, "exit");
+    Tcl_Eval(interp,normalExitCmd);
     exit(1);
 
 #if 0
