@@ -21,21 +21,32 @@ EXTERN char *exp_cmdfilename;
 EXTERN int exp_getpid;	/* pid of Expect itself */
 EXTERN int exp_buffer_command_input;
 
-extern int exp_tcl_debugger_available;
+EXTERN int exp_tcl_debugger_available;
+
+EXTERN Tcl_Interp *exp_interp;
 
 EXTERN int	Exp_Init EXP_PROTO((Tcl_Interp *));	/* for Tcl_AppInit apps */
 EXTERN void	exp_parse_argv EXP_PROTO((Tcl_Interp *,int argc,char **argv));
 EXTERN int	exp_interpreter EXP_PROTO((Tcl_Interp *));
-EXTERN void	exp_interpret_cmdfile EXP_PROTO((Tcl_Interp *,FILE *));
-EXTERN void	exp_interpret_cmdfilename EXP_PROTO((Tcl_Interp *,char *));
+EXTERN int	exp_interpret_cmdfile EXP_PROTO((Tcl_Interp *,FILE *));
+EXTERN int	exp_interpret_cmdfilename EXP_PROTO((Tcl_Interp *,char *));
 EXTERN void	exp_interpret_rcfiles EXP_PROTO((Tcl_Interp *,int my_rc,int sys_rc));
 
 EXTERN char *	exp_cook EXP_PROTO((char *s,int *len));
 
+EXTERN void	exp_close_on_exec _ANSI_ARGS_((int));
+
 			/* app-specific exit handler */
 EXTERN void	(*exp_app_exit)EXP_PROTO((Tcl_Interp *));
 EXTERN void	exp_exit EXP_PROTO((Tcl_Interp *,int status));
 EXTERN void	exp_exit_handlers EXP_PROTO((Tcl_Interp *));
-EXTERN void	exp_error _ANSI_ARGS_(VARARGS);
+
+EXTERN void	exp_error EXP_PROTOV (EXP_VARARGS(Tcl_Interp *,interp));
+
+/* Tcl 7.5 uses Tcl_AsyncReady().  Earlier versions use
+   tcl_AsyncReady, a variable.  */
+#if (TCL_MAJOR_VERSION == 7 && TCL_MINOR_VERSION >= 5) || TCL_MAJOR_VERSION > 7
+#  define tcl_AsyncReady Tcl_AsyncReady()
+#endif
 
 #endif /* _EXPECT_TCL_H */
